@@ -1,3 +1,5 @@
+import pygame_widgets
+from pygame_widgets import Mouse
 from pygame_widgets.widget import WidgetBase
 from pygame_widgets.textbox import TextBox
 from pygame_widgets.dropdown import Dropdown, DropdownChoice
@@ -10,9 +12,7 @@ class ComboBox(Dropdown):
             textboxKwargs=None,
             **kwargs
     ):
-        """Initialise a customisable combo box for Pygame.
-
-        The bar can be written on, and displays under it the results.
+        """Initialise a customisable combo box for Pygame. Acts like a searchable dropdown.
 
         :param win: Surface on which to draw
         :type win: pygame.Surface
@@ -49,7 +49,7 @@ class ComboBox(Dropdown):
                 textboxKwargs[key] = value
 
         self.textBar = TextBox(
-            win, x, y, width, height,
+            win, x, y, width, height, isSubWidget=True,
             onTextChanged=self.updateSearchResults,
             **textboxKwargs
         )
@@ -73,7 +73,7 @@ class ComboBox(Dropdown):
         """Create the widgets for the choices."""
         # We create the DropdownChoice(s)
         direction = kwargs.get('direction', 'down')
-        self.__choiceWidgets = []
+        self.__choices = []
         for i, text in enumerate(self.choices):
             if i == self.maxResults:
                 return
@@ -94,16 +94,10 @@ class ComboBox(Dropdown):
                 x = -(i + 1) * width
                 y = 0
 
-            self.__choiceWidgets.append(
+            self.__choices.append(
                 DropdownChoice(
-                    self.win,
-                    x,
-                    y,
-                    width,
-                    height,
-                    text=text,
-                    drop=self,
-                    value=i,
+                    self.win, x, y, width, height,
+                    text=text, dropdown=self, value=i,
                     last=(i == self.maxResults - 1),
                     **kwargs,
                 )
@@ -115,13 +109,13 @@ class ComboBox(Dropdown):
         :param events: Use pygame.event.get()
         :type events: list of pygame.event.Event
         """
-        if not self._hidden:
+        if not self._hidden and not self._disabled:
             # Keeps state of selected
             previouslySelected = self.textBar.selected
             self.textBar.listen(events)
 
-            if self.dropped:
-                for dropdownChoice in self.__choiceWidgets:
+            if self._dropped:
+                for dropdownChoice in self.__choices:
                     dropdownChoice.listen(events)
                     if dropdownChoice.clicked:
                         # The choice was clicked by user
@@ -131,7 +125,7 @@ class ComboBox(Dropdown):
             # Whether the search is started or stopped
             if previouslySelected and not self.textBar.selected:
                 self.onStopSearch(*self.onStopSearchParams)
-                self.dropped = False
+                self._dropped = False
 
             if not previouslySelected and self.textBar.selected:
                 self.onStartSearch(*self.onStartSearchParams)
@@ -141,34 +135,38 @@ class ComboBox(Dropdown):
         """Draw the widget."""
         if not self._hidden:
             self.textBar.draw()
-            if self.dropped:
+            if self._dropped:
                 # Find how many choices should be shown
                 numberVisible = min(len(self.suggestions), self.maxResults)
-                for i, dropdownChoice in enumerate(self.__choiceWidgets):
-                    # Define if the the drop down should be shown
+                for i, dropdownChoice in enumerate(self.__choices):
+                    # Define if the the dropdown should be shown
                     if i < numberVisible:
                         dropdownChoice.show()
+                        self.moveToTop()
                         # Choose the text to show
                         dropdownChoice.text = self.suggestions[i]
                     else:
                         dropdownChoice.hide()
                     dropdownChoice.draw()
 
+    def contains(self, x, y):
+        return super(Dropdown, self).contains(x, y) or \
+               (any([c.contains(x, y) for c in self.__choices]) and self._dropped)
+
     def updateSearchResults(self):
         """Update the suggested results based on selected text.
 
         Uses a 'contains' research. Could be improved by other
         search algorithms.
         """
-
         text = self.textBar.getText()
 
         if text != '':
             # Finds all the texts that start with the same text
             self.suggestions = self._searchAlgo(text, self.choices)
-            self.dropped = True
+            self._dropped = True
         else:
-            self.dropped = False
+            self._dropped = False
 
     def _searchAlgo(self, text, choices):
         """Return the suggestions of text in choices."""
@@ -193,13 +191,13 @@ class ComboBox(Dropdown):
 
 if __name__ == '__main__':
     import pygame
-    from pygame_widgets import Button
+    from pygame_widgets.button import Button
 
     pygame.init()
     win = pygame.display.set_mode((600, 600))
 
     comboBox = ComboBox(
-        win, 120, 10, 250, 50, name='Select Color',
+        win, 120, 10, 250, 50, name='Select Colour',
         choices=pygame.colordict.THECOLORS.keys(),
         maxResults=4,
         font=pygame.font.SysFont('calibri', 30),
@@ -213,7 +211,7 @@ if __name__ == '__main__':
 
 
     button = Button(
-        win, 10, 10, 100, 50, text='Set Color', fontSize=30,
+        win, 10, 10, 100, 50, text='Set Colour', fontSize=30,
         margin=15, inactiveColour=(200, 0, 100), pressedColour=(0, 255, 0),
         radius=5, onClick=output, font=pygame.font.SysFont('calibri', 18),
         textVAlign='bottom'
@@ -230,9 +228,5 @@ if __name__ == '__main__':
 
         win.fill((255, 255, 255))
 
-        comboBox.listen(events)
-        comboBox.draw()
-        button.listen(events)
-        button.draw()
-
+        pygame_widgets.update(events)
         pygame.display.update()
