@@ -1,7 +1,9 @@
 import pygame
 from pygame import gfxdraw
 
+import pygame_widgets
 from pygame_widgets.widget import WidgetBase
+from pygame_widgets.mouse import Mouse, MouseState
 
 
 class Toggle(WidgetBase):
@@ -17,8 +19,6 @@ class Toggle(WidgetBase):
         self.handleRadius = kwargs.get('handleRadius', int(self._height / 1.3))
         self.radius = self._height // 2
 
-        self.hidden = False
-        self.clicked = False
         self.colour = self.onColour if self.value else self.offColour
         self.handleColour = self.handleOnColour if self.value else self.handleOffColour
 
@@ -28,37 +28,30 @@ class Toggle(WidgetBase):
         self.handleColour = self.handleOnColour if self.value else self.handleOffColour
 
     def listen(self, events):
-        if not self._hidden:
-            pressed = pygame.mouse.get_pressed()[0]
-            x, y = pygame.mouse.get_pos()
+        if not self._hidden and not self._disabled:
+            mouseState = Mouse.getMouseState()
+            x, y = Mouse.getMousePos()
 
             if self.contains(x, y):
-                if pressed:
-                    if not self.clicked:
-                        self.clicked = True
-                        self.toggle()
-
-                elif self.clicked:
-                    self.clicked = False
-
-            elif not pressed:
-                self.clicked = False
+                if mouseState == MouseState.CLICK:
+                    self.toggle()
 
     def draw(self):
-        pygame.draw.rect(self.win, self.colour, (self._x, self._y, self._width, self._height))
+        if not self._hidden:
+            pygame.draw.rect(self.win, self.colour, (self._x, self._y, self._width, self._height))
 
-        pygame.draw.circle(self.win, self.colour, (self._x, self._y + self._height // 2), self.radius)
-        pygame.draw.circle(self.win, self.colour, (self._x + self._width, self._y + self._height // 2), self.radius)
+            pygame.draw.circle(self.win, self.colour, (self._x, self._y + self._height // 2), self.radius)
+            pygame.draw.circle(self.win, self.colour, (self._x + self._width, self._y + self._height // 2), self.radius)
 
-        circle = (
-            self._x + (
-                self._width - self.handleRadius + self.radius if self.value else self.handleRadius - self.radius
-            ),
-            self._y + self._height // 2
-        )
+            circle = (
+                self._x + (
+                    self._width - self.handleRadius + self.radius if self.value else self.handleRadius - self.radius
+                ),
+                self._y + self._height // 2
+            )
 
-        gfxdraw.filled_circle(self.win, *circle, self.handleRadius, self.handleColour)
-        gfxdraw.aacircle(self.win, *circle, self.handleRadius, self.handleColour)
+            gfxdraw.filled_circle(self.win, *circle, self.handleRadius, self.handleColour)
+            gfxdraw.aacircle(self.win, *circle, self.handleRadius, self.handleColour)
 
     def getValue(self):
         return self.value
@@ -81,7 +74,5 @@ if __name__ == '__main__':
 
         win.fill((255, 255, 255))
 
-        toggle.listen(events)
-        toggle.draw()
-
+        pygame_widgets.update(events)
         pygame.display.update()
